@@ -176,16 +176,20 @@ class Browser:
         from feeluown.gui.pages.search import render as render_search
         from feeluown.gui.pages.player_playlist import render as render_player_playlist
         from feeluown.gui.pages.model import render as render_model
-        from feeluown.gui.pages.similar_songs import render as render_similar_songs
-        from feeluown.gui.pages.comment import render as render_hot_comments
         from feeluown.gui.pages.coll_library import render as render_coll_library
+        from feeluown.gui.pages.song_explore import render as render_song_explore
 
         model_prefix = f'{MODEL_PAGE_PREFIX}<provider>'
 
+        async def dummy_render(req, *args, **kwargs):
+            warnings.warn(f'This route:{req.rule} will be removed.')
+
         urlpatterns = [
             (f'{model_prefix}/<ns>/<identifier>', render_model),
-            (f'{model_prefix}/songs/<identifier>/similar', render_similar_songs),
-            (f'{model_prefix}/songs/<identifier>/hot_comments', render_hot_comments),
+            # These routes will be removed in v3.9
+            (f'{model_prefix}/songs/<identifier>/similar', dummy_render),
+            (f'{model_prefix}/songs/<identifier>/hot_comments', dummy_render),
+            (f'{model_prefix}/songs/<identifier>/explore', render_song_explore),
             ('/colls/library', render_coll_library),
             ('/colls/<identifier>', self._render_coll),
             ('/search', render_search),
